pub(super) fn is_half_open(scope: &ScopeKey, target: BreakerTarget) -> boolExpand description
Whether the breaker’s cooldown has ended with no success since: the next iteration is a probe, and sends one item only.
pub(super) fn is_half_open(scope: &ScopeKey, target: BreakerTarget) -> boolWhether the breaker’s cooldown has ended with no success since: the next iteration is a probe, and sends one item only.