pub(super) fn is_open(scope: &ScopeKey, target: BreakerTarget) -> boolExpand description
Whether the phases target covers should skip this iteration.
pub(super) fn is_open(scope: &ScopeKey, target: BreakerTarget) -> boolWhether the phases target covers should skip this iteration.