pub(super) fn record_success(
scope: &ScopeKey,
target: BreakerTarget,
) -> Option<u32>Expand description
Returns the number of times this breaker had tripped, if this success closed it.
pub(super) fn record_success(
scope: &ScopeKey,
target: BreakerTarget,
) -> Option<u32>Returns the number of times this breaker had tripped, if this success closed it.