pub(super) fn snapshot(
scope: &ScopeKey,
target: BreakerTarget,
) -> BreakerSnapshotExpand description
Reads a breaker without touching it, for the dashboard. Not is_open, which clears an elapsed
cooldown as a side effect.
pub(super) fn snapshot(
scope: &ScopeKey,
target: BreakerTarget,
) -> BreakerSnapshotReads a breaker without touching it, for the dashboard. Not is_open, which clears an elapsed
cooldown as a side effect.